import { DeepPartial, EntityManager, Repository } from 'typeorm';
import { ConnectionResult, StandardDeleteResponse } from '../tgql';
import { BaseModel } from './';
import { StringMap, WhereInput } from './types';
export interface BaseOptions {
    manager?: EntityManager;
}
export declare class BaseService<E extends BaseModel> {
    protected entityClass: any;
    protected repository: Repository<E>;
    manager: EntityManager;
    columnMap: StringMap;
    klass: string;
    constructor(entityClass: any, repository: Repository<E>);
    getPageInfo(limit: number, offset: number, totalCount: number): {
        hasNextPage: boolean;
        hasPreviousPage: boolean;
        limit: number;
        offset: number;
        totalCount: number;
    };
    find<W extends WhereInput>(where?: any, orderBy?: string, limit?: number, offset?: number, fields?: string[]): Promise<E[]>;
    findConnection<W extends WhereInput>(where?: any, orderBy?: string, limit?: number, offset?: number, fields?: string[]): Promise<ConnectionResult<E>>;
    private buildFindQuery;
    findOne<W>(where: W): Promise<E>;
    create(data: DeepPartial<E>, userId: string, options?: BaseOptions): Promise<E>;
    createMany(data: DeepPartial<E>[], userId: string, options?: BaseOptions): Promise<E[]>;
    update<W extends any>(data: DeepPartial<E>, where: W, userId: string, options?: BaseOptions): Promise<E>;
    delete<W extends any>(where: W, userId: string, options?: BaseOptions): Promise<StandardDeleteResponse>;
    attrsToDBColumns: (attrs: string[]) => string[];
    attrToDBColumn: (attr: string) => string;
    static buildParamKey: (i: number) => string;
}
